cli

package
v0.1.5-0...-b5400da Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 22, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var DevRoot string

DevRoot optionally points local project builds at a Plumtree checkout's SDK.

Functions

func RunClean

func RunClean(args []string, in io.Reader, out, errOut io.Writer) int

RunClean is the selected root author workflow surface.

Types

This section is empty.

Directories

Path Synopsis
Package paired contains the clean private client used to manage paired Plumtree servers.
Package paired contains the clean private client used to manage paired Plumtree servers.
Package scaffold generates the standard Plumtree app layout for `pt new`:
Package scaffold generates the standard Plumtree app layout for `pt new`:
Package sshdev serves a Plumtree app over SSH for local development.
Package sshdev serves a Plumtree app over SSH for local development.
Package template exposes the embedded `pt new` project template.
Package template exposes the embedded `pt new` project template.
Package workflow contains the final, clean-break pt project and administration workflows.
Package workflow contains the final, clean-break pt project and administration workflows.

Jump to