Documentation
¶
Overview ¶
Package buildassets provides the SDK and TUI runtime bundled into the standalone control-plane binary for hermetic in-process builds.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Bundle ¶
type Bundle struct {
WorkspaceModules []string
GoProxy string
// contains filtered or unexported fields
}
Bundle is a materialized copy of the embedded build dependencies. Call Cleanup after the build backend has stopped using WorkspaceModules.
Click to show internal directories.
Click to hide internal directories.